# CHERAB-IMAS

<!-- BEGIN-HEADER -->

|         |                                                                                                                     |
| ------- | ------------------------------------------------------------------------------------------------------------------- |
| CI/CD   | [![CI][ci-badge]][ci] [![PyPI Publish][PyPI-publish-badge]][PyPi-publish] [![codecov][codecov-badge]][codecov]      |
| Docs    | [![Documentation][docs-badge]][docs]                                                                                |
| Package | [![PyPI - Version][pypi-badge]][pypi] [![Conda][conda-badge]][conda] [![PyPI - Python Version][python-badge]][pypi] |
| Meta    | [![License - EUPL-1.1][license-badge]][license] [![Pixi Badge][pixi-badge]][pixi-url]                               |

[ci]: https://github.com/cherab/imas/actions/workflows/ci.yaml
[ci-badge]: https://img.shields.io/github/actions/workflow/status/cherab/imas/ci.yaml?style=flat-square&logo=GitHub&label=CI
[codecov]: https://codecov.io/github/cherab/imas
[codecov-badge]: https://img.shields.io/codecov/c/github/cherab/imas?token=05LZGWUUXA&style=flat-square&logo=codecov
[conda]: https://prefix.dev/channels/conda-forge/packages/cherab-imas
[conda-badge]: https://img.shields.io/conda/vn/conda-forge/cherab-imas?logo=conda-forge&style=flat-square
[docs]: https://github.com/cherab/imas/actions/workflows/docs.yml
[docs-badge]: https://img.shields.io/github/actions/workflow/status/cherab/imas/docs.yml?style=flat-square&logo=GitHub&label=Docs
[license]: https://opensource.org/licenses/EUPL-1.1
[license-badge]: https://img.shields.io/badge/license-EUPL_1.1%20-blue?style=flat-square
[pixi-badge]: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/prefix-dev/pixi/main/assets/badge/v0.json&style=flat-square
[pixi-url]: https://pixi.sh
[pypi]: https://pypi.org/project/cherab-imas/
[pypi-badge]: https://img.shields.io/pypi/v/cherab-imas?label=PyPI&logo=pypi&logoColor=gold&style=flat-square
[pypi-publish]: https://github.com/cherab/imas/actions/workflows/deploy-pypi.yml
[pypi-publish-badge]: https://img.shields.io/github/actions/workflow/status/cherab/imas/deploy-pypi.yml?event=release&style=flat-square&logo=github&label=PyPI%20Publish
[python-badge]: https://img.shields.io/pypi/pyversions/cherab-imas?logo=Python&logoColor=gold&style=flat-square

---

[`cherab`](https://github.com/cherab/core) add-on module for **IMAS** (Integrated Modelling & Analysis Suite).

This module enables the creation of `cherab`'s functional objects (e.g. plasma, observers, meshes, etc.) from IMAS IDSs (Interface Data Structures).

<!-- END-HEADER -->

## 🌐 Install

**With `pip`:**

```
pip install cherab-imas
```

**With `mamba` / `conda`:**

```
mamba install -c conda-forge cherab-imas
```

## 📝 Documentation

See the [official documentation](https://cherab.github.io/imas/) to learn more.
